summaryrefslogtreecommitdiff
path: root/src/core/libs/lib-pacman.sh
diff options
context:
space:
mode:
authorNicolás Reynolds <fauno@kiwwwi.com.ar>2011-05-22 20:39:30 -0300
committerNicolás Reynolds <fauno@kiwwwi.com.ar>2011-05-22 20:39:30 -0300
commit24df19be6faa641aced0127de471a26d7f582db1 (patch)
tree23ae17aad5b29d3c8764e180c4b0c7bb61347e26 /src/core/libs/lib-pacman.sh
parent1dc28733f9853a51878403275c3b9e5f5edb74f1 (diff)
Removed mentions to [core] that assumed all required packages were there. Changed to base and base-devel.2011.05.22
Diffstat (limited to 'src/core/libs/lib-pacman.sh')
-rw-r--r--src/core/libs/lib-pacman.sh13
1 files changed, 7 insertions, 6 deletions
diff --git a/src/core/libs/lib-pacman.sh b/src/core/libs/lib-pacman.sh
index 495c545..7049735 100644
--- a/src/core/libs/lib-pacman.sh
+++ b/src/core/libs/lib-pacman.sh
@@ -97,20 +97,21 @@ EOF
# not sorted
list_package_groups ()
{
- $PACMAN_TARGET -Sg
+ echo -e "base\nbase-devel"
}
# List the packages in one or more repos or groups. output is one or more lines, each line being like this:
# <repo/group name> packagename [version, if $1=repo]
# lines are sorted by packagename
# $1 repo or group
# $2 one or more repo or group names
list_packages ()
{
- [ "$1" = repo -o "$1" = group ] || die_error "list_packages \$1 must be repo or group. not $1!"
- [ "$1" = repo ] && $PACMAN_TARGET -Sl $2
- [ "$1" = group ] && $PACMAN_TARGET -Sg $2
+ action=$1; shift
+ [ "$action" = repo -o "$action" = group ] || die_error "list_packages \$action must be repo or group. not $action!"
+ [ "$action" = repo ] && $PACMAN_TARGET -Sql $@
+ [ "$action" = group ] && $PACMAN_TARGET -Sqg $@
}
# find out the group to which one or more packages belong
@@ -97,20 +97,21 @@ EOF
# <repo/group name> packagename [version, if $1=repo]
# lines are sorted by packagename
-# $1 repo or group
-# $2 one or more repo or group names
+# $action repo or group
+# $@ one or more repo or group names
list_packages ()
{